@@ -7,9 +7,10 @@ from vortex.handler.TupleDataObservableHandler import TupleDataObservableHandler
 from .tuple_providers.CoordSetTupleProvider import CoordSetTupleProvider
 
 
-def makeTupleDataObservableHandler(diagramPluginViewerApi: DiagramViewerApiABC,
-                                   ormSessionCreator):
-    """" Make Tuple Data Observable Handler
+def makeTupleDataObservableHandler(
+    diagramPluginViewerApi: DiagramViewerApiABC, ormSessionCreator
+):
+    """ " Make Tuple Data Observable Handler
 
     This method creates the observable object, registers the tuple providers and then
     returns it.
@@ -21,10 +22,11 @@ def makeTupleDataObservableHandler(diagramPluginViewerApi: DiagramViewerApiABC,
 
     """
     tupleObservable = TupleDataObservableHandler(
-        observableName=gisDiagramObservableName,
-        additionalFilt=gisDiagramFilt)
+        observableName=gisDiagramObservableName, additionalFilt=gisDiagramFilt
+    )
 
     # Register TupleProviders here
-    tupleObservable.addTupleProvider(DiagramCoordSetTuple.tupleName(),
-                                     CoordSetTupleProvider(diagramPluginViewerApi))
+    tupleObservable.addTupleProvider(
+        DiagramCoordSetTuple.tupleName(), CoordSetTupleProvider(diagramPluginViewerApi)
+    )
     return tupleObservable
